namespace elm { namespace interface { 
#ifdef ELM_INTERFACE_ATSPI_ACCESSIBLE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Accessible::localized_role_name_get() const
{
   const char * __return_value =  ::elm_interface_atspi_accessible_localized_role_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACCESSIBLE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<Elm_Atspi_Relation_Set>::type Atspi_Accessible::relation_set_get() const
{
   Elm_Atspi_Relation_Set __return_value =  ::elm_interface_atspi_accessible_relation_set_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Atspi_Relation_Set>::type>(__return_value);
}
#endif
inline ::efl::eolian::return_traits<Elm_Atspi_Role>::type Atspi_Accessible::role_get() const
{
   Elm_Atspi_Role __return_value =  ::elm_interface_atspi_accessible_role_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Atspi_Role>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::role_set( ::efl::eolian::in_traits<Elm_Atspi_Role>::type role) const
{
    ::elm_interface_atspi_accessible_role_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Atspi_Role,  ::efl::eolian::in_traits<Elm_Atspi_Role>::type>(role));
}
#ifdef ELM_INTERFACE_ATSPI_ACCESSIBLE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<  ::efl::eina::list< ::elm::interface::Atspi_Accessible>>::type Atspi_Accessible::children_get() const
{
   Eina_List * __return_value =  ::elm_interface_atspi_accessible_children_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::list< ::elm::interface::Atspi_Accessible>>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACCESSIBLE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Accessible::role_name_get() const
{
   const char * __return_value =  ::elm_interface_atspi_accessible_role_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACCESSIBLE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<int>::type Atspi_Accessible::index_in_parent_get() const
{
   int __return_value =  ::elm_interface_atspi_accessible_index_in_parent_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Accessible::description_get() const
{
   const char * __return_value =  ::elm_interface_atspi_accessible_description_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::description_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type description) const
{
    ::elm_interface_atspi_accessible_description_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(description));
}
inline ::efl::eolian::return_traits< ::elm::interface::Atspi_Accessible>::type Atspi_Accessible::parent_get() const
{
    ::Elm_Interface_Atspi_Accessible* __return_value =  ::elm_interface_atspi_accessible_parent_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::interface::Atspi_Accessible>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::parent_set( ::efl::eolian::in_traits< ::elm::interface::Atspi_Accessible>::type parent) const
{
    ::elm_interface_atspi_accessible_parent_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_Interface_Atspi_Accessible*,  ::efl::eolian::in_traits< ::elm::interface::Atspi_Accessible>::type>(parent));
}
#ifdef ELM_INTERFACE_ATSPI_ACCESSIBLE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<Elm_Atspi_State_Set>::type Atspi_Accessible::state_set_get() const
{
   Elm_Atspi_State_Set __return_value =  ::elm_interface_atspi_accessible_state_set_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Atspi_State_Set>::type>(__return_value);
}
#endif
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Accessible::translation_domain_get() const
{
   const char * __return_value =  ::elm_interface_atspi_accessible_translation_domain_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::translation_domain_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type domain) const
{
    ::elm_interface_atspi_accessible_translation_domain_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(domain));
}
inline ::efl::eolian::return_traits<Elm_Atspi_Type>::type Atspi_Accessible::type_get() const
{
   Elm_Atspi_Type __return_value =  ::elm_interface_atspi_accessible_type_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Atspi_Type>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::type_set( ::efl::eolian::in_traits<Elm_Atspi_Type>::type type) const
{
    ::elm_interface_atspi_accessible_type_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Atspi_Type,  ::efl::eolian::in_traits<Elm_Atspi_Type>::type>(type));
}
inline ::efl::eolian::return_traits< ::eo::Base>::type Atspi_Accessible::root_get() const
{
    ::Eo_Base* __return_value =  ::elm_interface_atspi_accessible_root_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::eo::Base>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Atspi_Accessible::relationship_append( ::efl::eolian::in_traits<Elm_Atspi_Relation_Type>::type type,  ::efl::eolian::in_traits< ::elm::interface::Atspi_Accessible>::type relation_object) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_accessible_relationship_append(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Atspi_Relation_Type,  ::efl::eolian::in_traits<Elm_Atspi_Relation_Type>::type>(type)
      ,  ::efl::eolian::convert_to_c< ::Elm_Interface_Atspi_Accessible const*,  ::efl::eolian::in_traits< ::elm::interface::Atspi_Accessible>::type>(relation_object));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::relationship_remove( ::efl::eolian::in_traits<Elm_Atspi_Relation_Type>::type type,  ::efl::eolian::in_traits< ::elm::interface::Atspi_Accessible>::type relation_object) const
{
    ::elm_interface_atspi_accessible_relationship_remove(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Atspi_Relation_Type,  ::efl::eolian::in_traits<Elm_Atspi_Relation_Type>::type>(type)
      ,  ::efl::eolian::convert_to_c< ::Elm_Interface_Atspi_Accessible const*,  ::efl::eolian::in_traits< ::elm::interface::Atspi_Accessible>::type>(relation_object));
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::relationships_clear() const
{
    ::elm_interface_atspi_accessible_relationships_clear(this->_eo_ptr());
}
} } 
namespace eo_cxx {
namespace elm { namespace interface { 
#ifdef ELM_INTERFACE_ATSPI_ACCESSIBLE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Accessible::localized_role_name_get() const
{
   const char * __return_value =  ::elm_interface_atspi_accessible_localized_role_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACCESSIBLE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<Elm_Atspi_Relation_Set>::type Atspi_Accessible::relation_set_get() const
{
   Elm_Atspi_Relation_Set __return_value =  ::elm_interface_atspi_accessible_relation_set_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Atspi_Relation_Set>::type>(__return_value);
}
#endif
inline ::efl::eolian::return_traits<Elm_Atspi_Role>::type Atspi_Accessible::role_get() const
{
   Elm_Atspi_Role __return_value =  ::elm_interface_atspi_accessible_role_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Atspi_Role>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::role_set( ::efl::eolian::in_traits<Elm_Atspi_Role>::type role) const
{
    ::elm_interface_atspi_accessible_role_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Atspi_Role,  ::efl::eolian::in_traits<Elm_Atspi_Role>::type>(role));
}
#ifdef ELM_INTERFACE_ATSPI_ACCESSIBLE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<  ::efl::eina::list< ::elm::interface::Atspi_Accessible>>::type Atspi_Accessible::children_get() const
{
   Eina_List * __return_value =  ::elm_interface_atspi_accessible_children_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::list< ::elm::interface::Atspi_Accessible>>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACCESSIBLE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Accessible::role_name_get() const
{
   const char * __return_value =  ::elm_interface_atspi_accessible_role_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
#endif
#ifdef ELM_INTERFACE_ATSPI_ACCESSIBLE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<int>::type Atspi_Accessible::index_in_parent_get() const
{
   int __return_value =  ::elm_interface_atspi_accessible_index_in_parent_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
#endif
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Accessible::description_get() const
{
   const char * __return_value =  ::elm_interface_atspi_accessible_description_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::description_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type description) const
{
    ::elm_interface_atspi_accessible_description_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(description));
}
inline ::efl::eolian::return_traits< ::elm::interface::Atspi_Accessible>::type Atspi_Accessible::parent_get() const
{
    ::Elm_Interface_Atspi_Accessible* __return_value =  ::elm_interface_atspi_accessible_parent_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::interface::Atspi_Accessible>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::parent_set( ::efl::eolian::in_traits< ::elm::interface::Atspi_Accessible>::type parent) const
{
    ::elm_interface_atspi_accessible_parent_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_Interface_Atspi_Accessible*,  ::efl::eolian::in_traits< ::elm::interface::Atspi_Accessible>::type>(parent));
}
#ifdef ELM_INTERFACE_ATSPI_ACCESSIBLE_MIXIN_PROTECTED
inline ::efl::eolian::return_traits<Elm_Atspi_State_Set>::type Atspi_Accessible::state_set_get() const
{
   Elm_Atspi_State_Set __return_value =  ::elm_interface_atspi_accessible_state_set_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Atspi_State_Set>::type>(__return_value);
}
#endif
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Atspi_Accessible::translation_domain_get() const
{
   const char * __return_value =  ::elm_interface_atspi_accessible_translation_domain_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::translation_domain_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type domain) const
{
    ::elm_interface_atspi_accessible_translation_domain_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(domain));
}
inline ::efl::eolian::return_traits<Elm_Atspi_Type>::type Atspi_Accessible::type_get() const
{
   Elm_Atspi_Type __return_value =  ::elm_interface_atspi_accessible_type_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_Atspi_Type>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::type_set( ::efl::eolian::in_traits<Elm_Atspi_Type>::type type) const
{
    ::elm_interface_atspi_accessible_type_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Atspi_Type,  ::efl::eolian::in_traits<Elm_Atspi_Type>::type>(type));
}
inline ::efl::eolian::return_traits< ::eo::Base>::type Atspi_Accessible::root_get() const
{
    ::Eo_Base* __return_value =  ::elm_interface_atspi_accessible_root_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::eo::Base>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Atspi_Accessible::relationship_append( ::efl::eolian::in_traits<Elm_Atspi_Relation_Type>::type type,  ::efl::eolian::in_traits< ::elm::interface::Atspi_Accessible>::type relation_object) const
{
   Eina_Bool __return_value =  ::elm_interface_atspi_accessible_relationship_append(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Atspi_Relation_Type,  ::efl::eolian::in_traits<Elm_Atspi_Relation_Type>::type>(type)
      ,  ::efl::eolian::convert_to_c< ::Elm_Interface_Atspi_Accessible const*,  ::efl::eolian::in_traits< ::elm::interface::Atspi_Accessible>::type>(relation_object));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::relationship_remove( ::efl::eolian::in_traits<Elm_Atspi_Relation_Type>::type type,  ::efl::eolian::in_traits< ::elm::interface::Atspi_Accessible>::type relation_object) const
{
    ::elm_interface_atspi_accessible_relationship_remove(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Atspi_Relation_Type,  ::efl::eolian::in_traits<Elm_Atspi_Relation_Type>::type>(type)
      ,  ::efl::eolian::convert_to_c< ::Elm_Interface_Atspi_Accessible const*,  ::efl::eolian::in_traits< ::elm::interface::Atspi_Accessible>::type>(relation_object));
}
inline ::efl::eolian::return_traits<void>::type Atspi_Accessible::relationships_clear() const
{
    ::elm_interface_atspi_accessible_relationships_clear(this->_eo_ptr());
}
inline elm::interface::Atspi_Accessible::operator ::elm::interface::Atspi_Accessible() const { return *static_cast< ::elm::interface::Atspi_Accessible const*>(static_cast<void const*>(this)); }
inline elm::interface::Atspi_Accessible::operator ::elm::interface::Atspi_Accessible&() { return *static_cast< ::elm::interface::Atspi_Accessible*>(static_cast<void*>(this)); }
inline elm::interface::Atspi_Accessible::operator ::elm::interface::Atspi_Accessible const&() const { return *static_cast< ::elm::interface::Atspi_Accessible const*>(static_cast<void const*>(this)); }
} } }

